@@ -1,2 +1,2 @@
 from .auth import authenticate_with_github
-from src.gh_auth import exceptions
+from gh_auth import exceptions
